==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ms-MY/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategori aset',
    'category_name'  					=> 'Nama Kategori',
    'checkin_email'                     => 'Hantar e-mel kepada pengguna selepas semak masuk / semak keluar.',
    'checkin_email_notification'        => 'Pnegguna ini akan dihanter e-mel ketika semak masuk/semak keluar.',
    'clone'                             => 'Klon Kategori',
    'create'  							=> 'Cipta Kategori',
    'edit'                              => 'Kemaskini Kategori',
    'email_will_be_sent_due_to_global_eula' => '.',
    'email_will_be_sent_due_to_category_eula' => 'An email will be sent to the user because a EULA is set for this category.',
    'eula_text'							=> 'Kategori EULA',
    'eula_text_help'					=> 'Bidang ini membolehkan anda menyesuaikan EULA anda untuk jenis aset tertentu. Jika anda hanya mempunyai satu EULA untuk semua aset anda, anda boleh menyemak kotak di bawah untuk menggunakan lalai utama.',
    'name'                              => 'Nama Kategori',
    'require_acceptance'				=> 'Memerlukan pengguna untuk mengesahkan penerimaan aset dalam kategori ini.',
    'required_acceptance'				=> 'Pengguna ini akan diemail dengan pautan untuk mengesahkan penerimaan item ini.',
    'required_eula'						=> 'Pengguna ini akan menghantar e-mel salinan EULA',
    'no_default_eula'					=> 'Tiada EULA lalai utama dijumpai. Tambah satu dalam Tetapan.',
    'update'  							=> 'Kemaskini Kategori',
    'use_default_eula'					=> 'Gunakan <a href="#" data-toggle="modal" data-target="#eulaModal">pilihan utama lalai EULA</a> sebaliknya.',
    'use_default_eula_disabled'			=> '<del>Gunakan EULA lalai utama bukannya.</del> Tiada seting utama EULA ditetapkan. Sila tambah satu dalam Tetapan.',
    'use_default_eula_column'			=> 'Guna EULA lalai',

);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ms-MY/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategori aset',
    'category_name'  					=> 'Nama Kategori',
    'checkin_email'                     => 'Hantar e-mel kepada pengguna selepas semak masuk / semak keluar.',
    'checkin_email_notification'        => 'Pnegguna ini akan dihanter e-mel ketika semak masuk/semak keluar.',
    'clone'                             => 'Klon Kategori',
    'create'  							=> 'Cipta Kategori',
    'edit'                              => 'Kemaskini Kategori',
    'email_will_be_sent_due_to_global_eula' => 'An email will be sent to the user because the global EULA is being used.',
    'email_will_be_sent_due_to_category_eula' => 'An email will be sent to the user because a EULA is set for this category.',
    'eula_text'							=> 'Kategori EULA',
    'eula_text_help'					=> 'Bidang ini membolehkan anda menyesuaikan EULA anda untuk jenis aset tertentu. Jika anda hanya mempunyai satu EULA untuk semua aset anda, anda boleh menyemak kotak di bawah untuk menggunakan lalai utama.',
    'name'                              => 'Nama Kategori',
    'require_acceptance'				=> 'Memerlukan pengguna untuk mengesahkan penerimaan aset dalam kategori ini.',
    'required_acceptance'				=> 'Pengguna ini akan diemail dengan pautan untuk mengesahkan penerimaan item ini.',
    'required_eula'						=> 'Pengguna ini akan menghantar e-mel salinan EULA',
    'no_default_eula'					=> 'Tiada EULA lalai utama dijumpai. Tambah satu dalam Tetapan.',
    'update'  							=> 'Kemaskini Kategori',
    'use_default_eula'					=> 'Gunakan <a href="#" data-toggle="modal" data-target="#eulaModal">pilihan utama lalai EULA</a> sebaliknya.',
    'use_default_eula_disabled'			=> '<del>Gunakan EULA lalai utama bukannya.</del> Tiada seting utama EULA ditetapkan. Sila tambah satu dalam Tetapan.',
    'use_default_eula_column'			=> 'Guna EULA lalai',

);
